@@ -1,7 +1,7 @@
 from django import forms
 from django.utils import simplejson as json
 
-from widgets import JSONWidget
+from .widgets import JSONWidget
 
 
 class JSONFormField(forms.CharField):
@@ -18,14 +18,17 @@ class JSONFormField(forms.CharField):
         widget. So, if we have an object that isn't a string, then for now
         we will assume that is where it has come from.
         """
+        value = super(JSONFormField, self).clean(value)
+
         if not value:
             return value
+
         if isinstance(value, basestring):
             try:
                 return json.loads(value)
-            except Exception, exc:
+            except Exception as exc:
                 raise forms.ValidationError(
-                    u'JSON decode error: %s' % (unicode(exc),)
+                    'JSON decode error: %s' % (unicode(exc),)
                 )
         else:
             return value
